{ hostRegistry, zentralwerk, config, pkgs, lib, ... }:

{
  networking.hostName = "nix-build"; # Define your hostname.
  networking.useDHCP = false;
  networking.interfaces.enp6s18 = {
    ipv4.addresses = [{
      address = hostRegistry.hosts.nix-build.ip4;
      prefixLength = zentralwerk.lib.config.site.net.c3d2.subnet4Len;
    }];
    useDHCP = false;
  };
  networking.defaultGateway = "172.22.99.1";
  networking.firewall.allowedTCPPorts = [ 22 ];
  networking.nameservers = [ "172.20.73.8" "9.9.9.9" ];

  c3d2.users.polygon = true;
  
  imports = [
    ./hardware-configuration.nix
  ];

  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.efiSysMountPoint = "/boot";
    };

    tmpOnTmpfs = true;
    cleanTmpDir = true;

    kernelModules = [ "kvm-intel" ];
    binfmt.emulatedSystems = [ "armv6l-linux" "armv7l-linux" "aarch64-linux" ];
  };

  nix = {
    buildCores = 40;
    maxJobs = 4;
    package = lib.mkForce pkgs.nixUnstable;
    trustedUsers = [ "client" ];
    extraOptions = ''
      builders-use-substitutes = true
    '';
  };


  # time.timeZone = "Europe/Amsterdam";
  environment.systemPackages = with pkgs; [
    wget
    vim
    git
  ];

  services.openssh.enable = true;
  services.openssh.permitRootLogin = lib.mkForce "yes";

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?
}
