{ hostRegistry, config, pkgs, lib, strings, ... }:

let
  eth0 = "ens18";
in
{
  imports = [
    # Include the results of the hardware scan.
    ./hardware-configuration.nix
    # ../../config
    # ../../config/hq.nix
    # ../../config/shared.nix
  ];

  c3d2 = {
    users.k-ot = true;
    isInHq = true;
    mapHqHosts = true;
    hq.interface = eth0;
    mountCeph = "/mnt/cephfs";
  };

  sops.age.sshKeyPaths = [ "/etc/ssh/ssh_host_ed25519_key" ];

  boot.loader.grub = {
    enable = true;
    version = 2;
    efiSupport = true;
    devices = [ "nodev" ];
  };
  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.loader.efi.canTouchEfiVariables = true;
  systemd.enableEmergencyMode = false;

  networking = {
    hostName = "storage-ng";
    # usePredictableInterfacenames = false;
    interfaces."${eth0}" = {
      ipv4.addresses = [{
        address = hostRegistry.hosts.${config.networking.hostName}.ip4;
        prefixLength = 24;
      }];
      ipv6.addresses = [{
        address = hostRegistry.hosts.${config.networking.hostName}.ip6;
        prefixLength = 64;
      }];
    };

    defaultGateway.address = "172.22.99.4";
    defaultGateway.interface = eth0;
  };

  environment.systemPackages = with pkgs; [
    screen
    zsh
    lftp
    lsof
    psmisc
    git-annex

    mpv
    iotop
  ];

  programs.bash.enableCompletion = true;
  programs.mtr.enable = true;
  # programs.gnupg.agent = { enable = true; enableSSHSupport = true; };

  services.openssh = {
    enable = true;
    allowSFTP = true;
  };

  services.atftpd = {
    enable = true;
    root = "/mnt/cephfs/c3d2/tftp";
  };

  /* # Open ports in the firewall.
    networking.firewall.allowedTCPPorts = [
    23
    ];
    networking.firewall.allowedUDPPorts = [
    69
    ];
  */

  networking.firewall.enable = false;

  system.stateVersion = "19.03"; # Did you read the comment?
}
